pub struct ResolvedReference {
pub reference: Located<Reference>,
pub target: Option<String>,
pub resolution: Resolution,
}Expand description
A reference resolved (best-effort) to the path of the symbol it refers to.
Fields
reference: Located<Reference>The reference and the path it was found in.
target: Option<String>The defining path this reference resolves to, or None when ambiguous
or unresolved.
resolution: ResolutionWhy it resolved (or didn’t).